<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="126"/>
        <source>CPU load %1%</source>
        <translation>CPU 負載 %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>CPU 負載設定</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>通則</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>顯示文字</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>更新間隔：</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>進度條方向：</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>進度條寬度：</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>由下至上</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>由上至下</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>由左至右</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>由右至左</translation>
    </message>
</context>
</TS>
